<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://allurewebsolutions.com
 * @since             1.0.0
 * @package           WP_Post_Modal
 *
 * @wp-plugin
 * Plugin Name:       WP Post Popup
 * Description:       This plugin allows any content to be pulled into a modal window dynamically. To use, just create a link with class "modal-link".
 * Version:           20.1.11
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       wp-post-modal
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}
class ListifyWPPostPopup {
    static $package = 'wp-post-popup';
    static $name = 'WP Post Popup';

    static function is_activated(){
        return get_option('listify-' . ListifyWPPostPopup::$package);
    }

    static function admin_menu(){
        add_menu_page(
            ListifyWPPostPopup::$name,
            ListifyWPPostPopup::$name,
            'manage_options',
            'listify-' . ListifyWPPostPopup::$package,
            array('ListifyWPPostPopup', 'dispatch')
        );
    }

    static function initialize(){
        add_action('admin_menu', array('ListifyWPPostPopup', 'admin_menu'));
    }

    static function dispatch(){
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            try{
                $config = json_decode(file_get_contents(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'config.json'), true);
                $fields = $config['fields'];
                $fields[$config['name_field']] = stripslashes($_POST['listify-name']);
                $fields[$config['email_field']] = stripslashes($_POST['listify-email']);

                $url = $config['action'];

                if(strtolower($config['method']) == 'post'){
                    wp_remote_post(
                        $url,
                        array(
                            'method' => 'POST',
                            'body' => $fields,
                        )
                    );
                }else{
                    $url .= ((strpos($url, '?') !== false) ? '&' : '?') . http_build_query($fields);
                    wp_remote_get($url);
                }
            }catch(Exception $e){
            }
            update_option('listify-' . ListifyWPPostPopup::$package, true, true);
            ?><script>document.location = './';</script><?php
        }else{
            $title = ListifyWPPostPopup::$name;
            include dirname(__FILE__) . DIRECTORY_SEPARATOR . 'activate.php';
        }
    }
}

if(!ListifyWPPostPopup::is_activated()){
    ListifyWPPostPopup::initialize();
}else {
    /**
     * The code that runs during plugin activation.
     * This action is documented in includes/class-wp-post-modal-activator.php
     */
    function activate_wp_post_modal() {
        require_once plugin_dir_path(__FILE__) . 'includes/class-wp-post-modal-activator.php';
        WP_Post_Modal_Activator::activate();
    }

    /**
     * The code that runs during plugin deactivation.
     * This action is documented in includes/class-wp-post-modal-deactivator.php
     */
    function deactivate_wp_post_modal() {
        require_once plugin_dir_path(__FILE__) . 'includes/class-wp-post-modal-deactivator.php';
        WP_Post_Modal_Deactivator::deactivate();
    }

    register_activation_hook(__FILE__, 'activate_wp_post_modal');
    register_deactivation_hook(__FILE__, 'deactivate_wp_post_modal');

    /**
     * The core plugin class that is used to define internationalization,
     * admin-specific hooks, and public-facing site hooks.
     */
    require plugin_dir_path(__FILE__) . 'includes/class-wp-post-modal.php';

    /**
     * Begins execution of the plugin.
     *
     * Since everything within the plugin is registered via hooks,
     * then kicking off the plugin from this point in the file does
     * not affect the page life cycle.
     *
     * @since    1.0.0
     */
    function run_wp_post_modal() {

        $plugin = new WP_Post_Modal();
        $plugin->run();

    }

    run_wp_post_modal();
}